#!/usr/bin/python
#    This file is part of Tal4Rdf <http://champin.net/t4r/>
#    Copyright (C) 2008 Pierre-Antoine Champin <pchampin@liris.cnrs.fr>
#
#    Tal4Rdf is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Tal4Rdf is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public License
#    along with Tal4Rdf.  If not, see <http://www.gnu.org/licenses/>.

"""
This is an example WSGI file to be used whith a WSGI server (e.g. Apache with
mod_wsgi). It can also be used as a CGI program.
"""
from os import chdir
from os.path import abspath, join, dirname, getsize
import sys

dir = abspath(dirname(__file__))
index_html = join(dir, "index.html")
disclaimer = """

WARNING: To test demo/index.wsgi, you should now launch test/itest_demo.py

"""

try:
    from t4r.wsgi import engine, error, set_allowed_requests
except ImportError:
    # if not in PYTHONPATH, try to find the package in the current dir
    if dir not in sys.path: sys.path.append(dir)
    try:
        from t4r.wsgi import engine, error, set_allowed_requests
    except ImportError:
        print >>sys.stderr, disclaimer
        raise

from t4r import T4rGraphParsingError, T4rTemplateParsingError
set_allowed_requests(10)

def application(env, start_response):
    chdir(dir)
    if env.get("REQUEST_METHOD") == "GET" and not env.get("QUERY_STRING"):
        return display_form(env, start_response)
    else:
        try:
            return engine(env, start_response)
        except IOError, e:
            return error(env, start_response,
                         "500 Error loading a resource",
                         "500 Error loading a resource\n\n" + str(e))
        except T4rTemplateParsingError, e:
            return error(env, start_response,
                         "500 Error parsing the template",
                         "500 Error parsing the template\n\n" + str(e))
        except T4rGraphParsingError, e:
            return error(env, start_response,
                         "500 Error parsing the graph",
                         "500 Error parsing the graph\n\n" + str(e))

def display_form(env, start_response):
    start_response("200 OK", [
        ("content-type", "text/html; charset=UTF-8"),
        ("content-length", str(getsize(index_html))),
    ])
    f = open(index_html)
    for line in f:
        yield line
    f.close()

if __name__ == "__main__":
    from wsgiref.handlers import CGIHandler
    h = CGIHandler()
    h.error_body += disclaimer
    h.run(application)
