#    This file is part of Tal4Rdf <http://champin.net/t4r/>
#    Copyright (C) 2008 Pierre-Antoine Champin <pchampin@liris.cnrs.fr>
#
#    Tal4Rdf is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Tal4Rdf is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public License
#    along with Tal4Rdf.  If not, see <http://www.gnu.org/licenses/>.

from os.path import dirname, join
from cStringIO import StringIO

from simpletal.simpleTALES import PathNotFoundException

from t4r.context import QNameContext
from t4r.graph import TalesGraph
from t4r.path import RdfPath

def test_without_qname_without_ns():
    c = QNameContext()
    c.evaluate("options") is None
    try: c.evaluate("foaf:name")
    except ValueError: pass
    else: assert 0, "PathNotFoundException expected"

def test_without_qname_with_ns():
    c = QNameContext()
    c.addGlobal("t4rns:foaf", "http://xmlns.com/foaf/0.1/")
    try: c.evaluate("foaf:name")
    except ValueError: pass
    else: assert 0, "ValueError expected"

def test_with_graph_without_ns():
    c = QNameContext()
    g = TalesGraph.from_stream(StringIO(""), c, "empty.ttl")
    c.set_graph_and_resource(g, RdfPath.for_resource(g, "http://example.com/"))
    try: c.evaluate("foaf:name")
    except PathNotFoundException: pass
    else: assert 0, "unexpected PathNotFoundException"

def test_with_graph_with_ns():
    c = QNameContext()
    g = TalesGraph.from_stream(StringIO(""), c, "empty.ttl")
    c.set_graph_and_resource(g, RdfPath.for_resource(g, "http://example.com/"))
    c.addGlobal("t4rns:foaf", "http://xmlns.com/foaf/0.1/")
    try: c.evaluate("foaf:name")
    except PathNotFoundException: assert 0, "unexpected PathNotFoundException"

def test_with_node_without_ns():
    c = QNameContext()
    g = TalesGraph.from_stream(StringIO(""), c, "empty.ttl")
    r = RdfPath.for_resource(g, "http://champin.net/foaf.rdf#pa")
    c.set_graph_and_resource(g, r)
    try: c.evaluate("foaf:name")
    except PathNotFoundException: pass
    else: assert 0, "unexpected PathNotFoundException"

def test_with_node_with_ns():
    c = QNameContext()
    c.addGlobal("t4rns:foaf", "http://xmlns.com/foaf/0.1/")
    f = open(join(dirname(__file__), "data.ttl"))
    g = TalesGraph.from_stream(f, c)
    f.close()
    r = RdfPath.for_resource(g, ex.jd)
    c.set_graph_and_resource(g, r)
    c.addGlobal("t4rns:foaf", getattr(foaf,""))
    c.addGlobal("t4rns:dc", getattr(dc,""))
    assert r["foaf:name"] is not None
    assert r["dc:creator:-"] is not None
    assert r["foaf:name:-"] is not None
    try: c.evaluate("foaf:name")
    except PathNotFoundException: assert 0, "unexpected PathNotFoundException"
    try: c.evaluate("dc:creator:-")
    except PathNotFoundException: assert 0, "unexpected PathNotFoundException"
    try: c.evaluate("foaf:name:-")
    except PathNotFoundException: assert 0, "unexpected PathNotFoundException"

def test_readonly_qnames():
    c = QNameContext()
    try: c.addGlobal("a:b", "foo")
    except TypeError: pass
    else: assert 0, "qnames should be readonly (global)"
    try: c.setLocal("a:b", "foo")
    except TypeError: pass
    else: assert 0, "qnames should be readonly (local)"

def test_unsafe_namespaces():
    c = QNameContext()
    for i in ["path", "exists", "nocall", "not", "string", "python"]:
        try: c.addGlobal("t4rns:%i" % i)
        except TypeError: pass
        else: assert 0, "unsafe namespace %s should not be allowed" % i

# ================ Test machinery ================

import log_4_test
log_4_test # just to make pyflakes happy

from uris_4_tests import add_global_generators
ex, foaf, dc = (None,)*3 # just to make pyflakes happy
add_global_generators(globals()) # this adds NS variables in the global scope

#
