#    This file is part of Tal4Rdf <http://champin.net/t4r/>
#    Copyright (C) 2008 Pierre-Antoine Champin <pchampin@liris.cnrs.fr>
#
#    Tal4Rdf is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Tal4Rdf is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public License
#    along with Tal4Rdf.  If not, see <http://www.gnu.org/licenses/>.

from os.path import dirname, join

from t4r.mimetype import parse_mimetype, unparse_mimetype, strip_params, \
                         guess_stream_mimetype, rdf_urlopen

def test_parse_mimetype():

    def check(expected, mimetype):
        trial = parse_mimetype(mimetype)
        assert trial == expected, "\n%r\n%r" % (trial, expected)

    check(("text", "*", {}), "text")
    check(("text", "html", {}), "text/html")
    check(("text", "html", {"charset":"utf-8"}), "text/html; charset = utf-8")
    check(("text", "html", {"charset":"utf-8", "foobar":"baz"}),
           "text/html; charset = utf-8 ; foobar = baz")

def test_unparse_mimertype():
    def check(expected, parsed):
        trial = unparse_mimetype(*parsed)
        assert trial == expected, "\n%r\n%r" % (trial, expected)

    check("text/*", ("text", "*", {}))
    check("text/html", ("text", "html", {}))
    check("text/html;charset=utf-8", ("text", "html", {"charset":"utf-8"}))

    trial = unparse_mimetype("text", "html", {"charset":"utf-8", "foobar":"baz"})
    expected = set ([
            "text/html;charset=utf-8;foobar=baz",
            "text/html;foobar=baz;charset=utf-8",
    ])
    assert trial in expected, trial

def test_strip_params():
    assert strip_params("text/*") == "text/*"
    assert strip_params("text/html") == "text/html"
    assert strip_params("text/html;charset=utf8") == "text/html"

def test_guess_stream_mimetype():
    dir = dirname(__file__)
    f = open(join(dir, "..", "test", "data.ttl"))
    try:
        assert guess_stream_mimetype(f) == "application/turtle"
    finally:
        f.close()
    f = rdf_urlopen("http://champin.net/foaf.rdf")
    try:
        assert guess_stream_mimetype(f) == "application/rdf+xml"
    finally:
        f.close()

def test_rdf_urlopen():
    f = rdf_urlopen("http://dbpedia.org/resource/Dublin")
    # this page (as all 'resource' pages in dbpedia) has content negociation
    # so we check here that we actually ask for RDF rather than HTML
    mimetype = f.info().get("content-type")
    f.close()
    assert mimetype.startswith("application/rdf+xml")

