#    This file is part of Tal4Rdf <http://champin.net/t4r/>
#    Copyright (C) 2008 Pierre-Antoine Champin <pchampin@liris.cnrs.fr>
#
#    Tal4Rdf is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Tal4Rdf is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public License
#    along with Tal4Rdf.  If not, see <http://www.gnu.org/licenses/>.

from t4r.species import register_species, unregister_species, guess_species, \
                        HTML, XML, OTHER

def check(expected, mimetype):
    trial = guess_species(mimetype)
    assert expected == trial, "%r %r" % (trial, expected)

def test_simple():
    check(HTML, "text/html")
    check(HTML, "text/html; charset=utf-8")
    check(XML, "text/xml")
    check(XML, "text/xml; charset=utf-8")
    check(XML, "application/xml")
    check(XML, "application/xml; charset=utf-8")
    check(OTHER, "text/plain")
    check(OTHER, "text/plain; charset=utf-8")
    check(OTHER, "text/n3")
    check(OTHER, "text/n3; charset=utf-8")
    check(OTHER, "foo/bar")
    check(OTHER, "foo/bar; charset=utf-8")

def test_heuristic():
    check(XML, "image/svg+xml")
    check(XML, "image/svg+xml; charset=utf-8")
    check(XML, "application/rdf+xml")
    check(XML, "application/rdf+xml; charset=utf-8")
    check(XML, "application/xhtml+xml")
    check(XML, "application/xhtml+xml; charset=utf-8")
    check(XML, "foo/bar+xml")
    check(XML, "foo/bar+xml; charset=utf-8")

def test_register():
    check(OTHER, "foo/bar")
    check(OTHER, "foo/bar; charset=utf-8")
    register_species("foo/bar", XML)

    try: register_species("foo/bar", HTML)
    except ValueError: pass
    else: assert 0, "TypeError expected when reregistering foo/bar"

    try: register_species("foo/bar", XML)
    except ValueError: assert 0, "Unexpected TypeError when reregistering foo/bar"

    check(XML, "foo/bar")
    check(XML, "foo/bar; charset=utf-8")
    unregister_species("foo/bar")
    check(OTHER, "foo/bar")
    check(OTHER, "foo/bar; charset=utf-8")


#
