#    This file is part of Tal4Rdf <http://champin.net/t4r/>
#    Copyright (C) 2008 Pierre-Antoine Champin <pchampin@liris.cnrs.fr>
#
#    Tal4Rdf is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Lesser General Public License as published
#    by the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Tal4Rdf is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public License
#    along with Tal4Rdf.  If not, see <http://www.gnu.org/licenses/>.

n3 = """
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
@prefix foaf: <http://xmlns.com/foaf/0.1/> .
@prefix ex: <http://example.org/terms/> .

ex:jd a foaf:Person ;
    foaf:firstname "John" ;
    foaf:lastname "Doe" ;
    foaf:knows [ a rdf:Seq ;
        rdf:_1 [ a foaf:Person ;
            foaf:name "Jane Doe"
        ] ;
        rdf:_2 [ a foaf:Person ;
            foaf:name "Paul Smith"
        ] ;
        rdf:_3 [ a foaf:Person ;
            foaf:name "George"
        ]
    ] ;
    foaf:nick "jd" .
# it is not correct to use an rdf:Seq with foaf:knows,
# but this guarantess the order, so we can test it.
"""

html_surounding = """
<html>
<head><title>Some HTML</title></head>
<body>
<h1>Some HTML</h1>
<br>%s
</body></html>
"""

txt_tal = """<tal:block tal:define="
    global t4rns:foaf string:http://xmlns.com/foaf/0.1/;
    global t4rns:ex string:http://example.org/terms/;
    global t4r:display string:strict"
/>
My name is <tal:block
  tal:replace="string:${foaf:firstname} ${foaf:lastname}" />.

I know:<tal:block tal:repeat="k foaf:knows/iterSeq">
<tal:block tal:content="string:* ${k/foaf:name}"
/></tal:block>

test1=<tal:block tal:replace="foaf:img" />
test2=<tal:block tal:replace="foaf:img/uri" />
test3=<tal:block tal:replace="foaf:knows/uri" />
test4=<tal:block tal:replace="foaf:knows/foo/bar" />
"""

txt_expected = """
My name is John Doe.

I know:
* Jane Doe
* Paul Smith
* George

test1={0 nodes}
test2=
test3=
test4={RDF-Path ERROR: invalid path step: foaf:knows/foo}
"""

from difflib import unified_diff

from t4r import render_template, make_typed_stream

def _mydiff(expected, trial):
    trial = trial.split("\n")
    expected = expected.split("\n")
    return "\n"+"\n".join(unified_diff(expected, trial))

def test_html():
    html_tal = html_surounding % txt_tal
    expected = html_surounding % txt_expected
    rdf = make_typed_stream(n3, "text/n3")
    tpl = make_typed_stream(html_tal, "text/html")
    out = render_template(tpl, "http://example.org/terms/jd", rdf)
    trial = out.read()
    assert trial == expected, _mydiff(expected, trial)

def test_non_xml():
    rdf = make_typed_stream(n3, "text/n3")
    tpl = make_typed_stream(txt_tal, "text/plain")
    out = render_template(tpl, "http://example.org/terms/jd", rdf)
    trial = out.read()
    assert trial == txt_expected, _mydiff(txt_expected, trial)

# ================ Test machinery ================

import log_4_test
log_4_test # just to make pyflakes happy

